    	move:
    		gene = the gene that the move is allowed for
    		spot = the order # of the address in that gene

    			for example:
    				address: "EEC_448_2:1"

    				might have 29 orders in gene 1,
    				each order needs to have the consecutive
    				order number.

    	region:
    		spot:
    			This is the actual sort order of the sequence
    			in the gene.

    	{
    		"strand": {
    			"move": {
    				"petition": "founder: produce traits",
    				"freight": {
    					"address": "EEC_448_2:...",
    					"amount": "1e32",
    					"fee": "0"
    				},
    				"gene": 1,
    				"spot": 1
    			},
    			"signature": "",
    			"votes": {}
    		},
    		"order": {
    			"gene": 1,
    			"spot": 9
    		}
    	}